@@ -1,18 +1,22 @@
 #!/usr/bin/env python3
 
+from __future__ import annotations
+
 import sys
+from pathlib import Path
 
 from ruamel.yaml import YAML
 
 
-def main():
+def main() -> int:
     yaml = YAML()
     for filename in sys.argv[1:]:
-        with open(filename) as file:
+        with Path(filename).open('r') as file:
             data = yaml.load(file)
-        with open(filename, 'w') as file:
+        with Path(filename).open('w') as file:
             yaml.dump(data, file)
+    return 0
 
 
 if __name__ == '__main__':
-    main()
+    raise SystemExit(main())
