@@ -338,8 +338,8 @@ func (s *ExternalDiffSystem) runDiffCommand(destAbsPath, targetAbsPath AbsPath)
 
 	// Swallow exit status 1 errors if the files differ as diff commands
 	// traditionally exit with code 1 in this case.
-	var exitError *exec.ExitError
-	if errors.As(err, &exitError) && exitError.ProcessState.ExitCode() == 1 {
+	if exitError := (&exec.ExitError{}); errors.As(err, &exitError) &&
+		exitError.ProcessState.ExitCode() == 1 {
 		destData, err2 := s.ReadFile(destAbsPath)
 		switch {
 		case errors.Is(err2, fs.ErrNotExist):
