@@ -1,10 +1,11 @@
 package cmd
 
 import (
+	"io/fs"
 	"runtime"
 	"testing"
 
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-vfs/v4/vfst"
 
@@ -14,22 +15,22 @@ import (
 func TestAddCmd(t *testing.T) {
 	for _, tc := range []struct {
 		name  string
-		root  interface{}
+		root  any
 		args  []string
-		tests []interface{}
+		tests []any
 	}{
 		{
 			name: "dir",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".dir": &vfst.Dir{Perm: 0o777},
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".dir": &vfst.Dir{Perm: fs.ModePerm},
 				},
 			},
 			args: []string{"~/.dir"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir",
 					vfst.TestIsDir,
-					vfst.TestModePerm(0o777&^chezmoitest.Umask),
+					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/.keep",
 					vfst.TestContents(nil),
@@ -39,21 +40,21 @@ func TestAddCmd(t *testing.T) {
 		},
 		{
 			name: "dir_with_file",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".dir": &vfst.Dir{
-						Perm: 0o777,
-						Entries: map[string]interface{}{
+						Perm: fs.ModePerm,
+						Entries: map[string]any{
 							"file": "# contents of .dir/file\n",
 						},
 					},
 				},
 			},
 			args: []string{"~/.dir"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir",
 					vfst.TestIsDir,
-					vfst.TestModePerm(0o777&^chezmoitest.Umask),
+					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/.keep",
 					vfst.TestDoesNotExist,
@@ -67,21 +68,21 @@ func TestAddCmd(t *testing.T) {
 		},
 		{
 			name: "dir_with_file_with_--recursive=false",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".dir": &vfst.Dir{
-						Perm: 0o777,
-						Entries: map[string]interface{}{
+						Perm: fs.ModePerm,
+						Entries: map[string]any{
 							"file": "# contents of .dir/file\n",
 						},
 					},
 				},
 			},
 			args: []string{"~/.dir", "--recursive=false"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir",
 					vfst.TestIsDir,
-					vfst.TestModePerm(0o777&^chezmoitest.Umask),
+					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_dir/.keep",
 					vfst.TestContents(nil),
@@ -94,21 +95,21 @@ func TestAddCmd(t *testing.T) {
 		},
 		{
 			name: "dir_private_unix",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".dir": &vfst.Dir{
 						Perm: 0o700,
-						Entries: map[string]interface{}{
+						Entries: map[string]any{
 							"file": "# contents of .dir/file\n",
 						},
 					},
 				},
 			},
 			args: []string{"~/.dir"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/private_dot_dir",
 					vfst.TestIsDir,
-					vfst.TestModePerm(0o777&^chezmoitest.Umask),
+					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/private_dot_dir/.keep",
 					vfst.TestDoesNotExist,
@@ -122,21 +123,21 @@ func TestAddCmd(t *testing.T) {
 		},
 		{
 			name: "dir_file_private_unix",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".dir": &vfst.Dir{
 						Perm: 0o700,
-						Entries: map[string]interface{}{
+						Entries: map[string]any{
 							"file": "# contents of .dir/file\n",
 						},
 					},
 				},
 			},
 			args: []string{"~/.dir/file"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/private_dot_dir",
 					vfst.TestIsDir,
-					vfst.TestModePerm(0o777&^chezmoitest.Umask),
+					vfst.TestModePerm(fs.ModePerm&^chezmoitest.Umask),
 				),
 				vfst.TestPath("/home/user/.local/share/chezmoi/private_dot_dir/.keep",
 					vfst.TestDoesNotExist,
@@ -150,27 +151,13 @@ func TestAddCmd(t *testing.T) {
 		},
 		{
 			name: "empty",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".empty": "",
 				},
 			},
 			args: []string{"~/.empty"},
-			tests: []interface{}{
-				vfst.TestPath("/home/user/.local/share/chezmoi/empty_dot_empty",
-					vfst.TestDoesNotExist,
-				),
-			},
-		},
-		{
-			name: "empty_with_--empty",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
-					".empty": "",
-				},
-			},
-			args: []string{"--empty", "~/.empty"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/empty_dot_empty",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -180,16 +167,16 @@ func TestAddCmd(t *testing.T) {
 		},
 		{
 			name: "executable_unix",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".executable": &vfst.File{
-						Perm:     0o777,
+						Perm:     fs.ModePerm,
 						Contents: []byte("#!/bin/sh\n"),
 					},
 				},
 			},
 			args: []string{"~/.executable"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/executable_dot_executable",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -199,13 +186,13 @@ func TestAddCmd(t *testing.T) {
 		},
 		{
 			name: "file",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".file": "# contents of .file\n",
 				},
 			},
 			args: []string{"~/.file"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_file",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -215,15 +202,15 @@ func TestAddCmd(t *testing.T) {
 		},
 		{
 			name: "symlink",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".symlink": &vfst.Symlink{
 						Target: ".dir/subdir/file",
 					},
 				},
 			},
 			args: []string{"~/.symlink"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/symlink_dot_symlink",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -233,8 +220,8 @@ func TestAddCmd(t *testing.T) {
 		},
 		{
 			name: "symlink_with_--follow",
-			root: map[string]interface{}{
-				"/home/user": map[string]interface{}{
+			root: map[string]any{
+				"/home/user": map[string]any{
 					".file": "# contents of .file\n",
 					".symlink": &vfst.Symlink{
 						Target: ".file",
@@ -242,7 +229,7 @@ func TestAddCmd(t *testing.T) {
 				},
 			},
 			args: []string{"--follow", "~/.symlink"},
-			tests: []interface{}{
+			tests: []any{
 				vfst.TestPath("/home/user/.local/share/chezmoi/dot_symlink",
 					vfst.TestModeIsRegular,
 					vfst.TestModePerm(0o666&^chezmoitest.Umask),
@@ -254,7 +241,10 @@ func TestAddCmd(t *testing.T) {
 		t.Run(tc.name, func(t *testing.T) {
 			chezmoitest.SkipUnlessGOOS(t, tc.name)
 			chezmoitest.WithTestFS(t, tc.root, func(fileSystem vfs.FS) {
-				require.NoError(t, newTestConfig(t, fileSystem).execute(append([]string{"add"}, tc.args...)))
+				assert.NoError(
+					t,
+					newTestConfig(t, fileSystem).execute(append([]string{"add"}, tc.args...)),
+				)
 				vfst.RunTests(t, fileSystem, "", tc.tests...)
 			})
 		})
@@ -266,13 +256,16 @@ func TestAddCmdChmod(t *testing.T) {
 		t.Skip("skipping UNIX test on Windows")
 	}
 
-	chezmoitest.WithTestFS(t, map[string]interface{}{
-		"/home/user": map[string]interface{}{
+	chezmoitest.WithTestFS(t, map[string]any{
+		"/home/user": map[string]any{
 			".dir/subdir/file": "# contents of .dir/subdir/file\n",
 		},
 	}, func(fileSystem vfs.FS) {
-		require.NoError(t, newTestConfig(t, fileSystem).execute([]string{"add", "/home/user/.dir"}))
-		require.NoError(t, fileSystem.Chmod("/home/user/.dir/subdir", 0o700))
-		require.NoError(t, newTestConfig(t, fileSystem).execute([]string{"add", "--force", "/home/user/.dir"}))
+		assert.NoError(t, newTestConfig(t, fileSystem).execute([]string{"add", "/home/user/.dir"}))
+		assert.NoError(t, fileSystem.Chmod("/home/user/.dir/subdir", 0o700))
+		assert.NoError(
+			t,
+			newTestConfig(t, fileSystem).execute([]string{"add", "--force", "/home/user/.dir"}),
+		)
 	})
 }
