@@ -11,6 +11,7 @@ import (
 type interactiveTemplateFuncsConfig struct {
 	forcePromptOnce bool
 	promptBool      map[string]string
+	promptChoice    map[string]string
 	promptDefaults  bool
 	promptInt       map[string]int
 	promptString    map[string]string
@@ -35,6 +36,12 @@ func (c *Config) addInteractiveTemplateFuncFlags(flags *pflag.FlagSet) {
 		c.interactiveTemplateFuncs.promptBool,
 		"Populate promptBool",
 	)
+	flags.StringToStringVar(
+		&c.interactiveTemplateFuncs.promptChoice,
+		"promptChoice",
+		c.interactiveTemplateFuncs.promptChoice,
+		"Populate promptChoice",
+	)
 	flags.StringToIntVar(
 		&c.interactiveTemplateFuncs.promptInt,
 		"promptInt",
@@ -77,7 +84,7 @@ func (c *Config) promptBoolOnceInteractiveTemplateFunc(
 	args ...bool,
 ) bool {
 	if len(args) > 1 {
-		err := fmt.Errorf("want 2 or 3 arguments, got %d", len(args)+2)
+		err := fmt.Errorf("want 3 or 4 arguments, got %d", len(args)+2)
 		panic(err)
 	}
 
@@ -101,6 +108,59 @@ func (c *Config) promptBoolOnceInteractiveTemplateFunc(
 	return c.promptBoolInteractiveTemplateFunc(prompt, args...)
 }
 
+func (c *Config) promptChoiceInteractiveTemplateFunc(
+	prompt string,
+	choices []any,
+	args ...string,
+) string {
+	if len(args) > 1 {
+		err := fmt.Errorf("want 2 or 3 arguments, got %d", len(args)+2)
+		panic(err)
+	}
+
+	if valueStr, ok := c.interactiveTemplateFuncs.promptChoice[prompt]; ok {
+		return valueStr
+	}
+
+	choiceStrs, err := anySliceToStringSlice(choices)
+	if err != nil {
+		panic(err)
+	}
+
+	value, err := c.promptChoice(prompt, choiceStrs, args...)
+	if err != nil {
+		panic(err)
+	}
+	return value
+}
+
+func (c *Config) promptChoiceOnceInteractiveTemplateFunc(
+	m map[string]any,
+	path any,
+	prompt string,
+	choices []any,
+	args ...string,
+) string {
+	if len(args) > 1 {
+		err := fmt.Errorf("want 4 or 5 arguments, got %d", len(args)+4)
+		panic(err)
+	}
+
+	nestedMap, lastKey, err := nestedMapAtPath(m, path)
+	if err != nil {
+		panic(err)
+	}
+	if !c.interactiveTemplateFuncs.forcePromptOnce {
+		if value, ok := nestedMap[lastKey]; ok {
+			if valueStr, ok := value.(string); ok {
+				return valueStr
+			}
+		}
+	}
+
+	return c.promptChoiceInteractiveTemplateFunc(prompt, choices, args...)
+}
+
 func (c *Config) promptIntInteractiveTemplateFunc(prompt string, args ...int64) int64 {
 	if len(args) > 1 {
 		err := fmt.Errorf("want 1 or 2 arguments, got %d", len(args)+1)
@@ -186,3 +246,18 @@ func (c *Config) promptStringOnceInteractiveTemplateFunc(
 
 	return c.promptStringInteractiveTemplateFunc(prompt, args...)
 }
+
+func anySliceToStringSlice(slice []any) ([]string, error) {
+	result := make([]string, 0, len(slice))
+	for _, elem := range slice {
+		switch elem := elem.(type) {
+		case []byte:
+			result = append(result, string(elem))
+		case string:
+			result = append(result, elem)
+		default:
+			return nil, fmt.Errorf("%v: not a string", elem)
+		}
+	}
+	return result, nil
+}
