@@ -7,8 +7,8 @@ import (
 	"bytes"
 	"errors"
 	"fmt"
-	"os"
-	"os/exec"
+	"io/fs"
+	"path/filepath"
 	"regexp"
 	"strings"
 
@@ -21,7 +21,6 @@ var (
 	mackupCommentRx  = regexp.MustCompile(`\A#.*\z`)
 	mackupKeyValueRx = regexp.MustCompile(`\A(\w+)\s*=\s*(.*)\z`)
 	mackupSectionRx  = regexp.MustCompile(`\A\[(.*)\]\z`)
-	mackupVersionRx  = regexp.MustCompile(`\AMackup\s+(\d+\.\d+\.\d+)\s*\z`)
 )
 
 type mackupApplicationApplicationConfig struct {
@@ -77,7 +76,7 @@ func (c *Config) runMackupAddCmd(
 	for _, arg := range args {
 		configRelPath := chezmoi.NewRelPath(arg + ".cfg")
 		data, err := c.baseSystem.ReadFile(mackupDirAbsPath.Join(configRelPath))
-		if errors.Is(err, os.ErrNotExist) {
+		if errors.Is(err, fs.ErrNotExist) {
 			data, err = c.baseSystem.ReadFile(mackupApplicationsDir.Join(configRelPath))
 		}
 		if err != nil {
@@ -122,49 +121,42 @@ func (c *Config) runMackupAddCmd(
 }
 
 func (c *Config) mackupApplicationsDir() (chezmoi.AbsPath, error) {
-	brewPrefixCmd := exec.Command("brew", "--prefix")
-	brewPrefixData, err := brewPrefixCmd.Output()
+	mackupBinaryPath, err := chezmoi.LookPath("mackup")
 	if err != nil {
 		return chezmoi.EmptyAbsPath, err
 	}
-	brewPrefix := chezmoi.NewAbsPath(strings.TrimRight(string(brewPrefixData), "\n"))
-
-	mackupVersionCmd := exec.Command("mackup", "--version")
-	mackupVersionData, err := mackupVersionCmd.Output()
+	mackupBinaryPathResolved, err := filepath.EvalSymlinks(mackupBinaryPath)
 	if err != nil {
 		return chezmoi.EmptyAbsPath, err
 	}
-	mackupVersionMatch := mackupVersionRx.FindSubmatch(mackupVersionData)
-	if mackupVersionMatch == nil {
-		return chezmoi.EmptyAbsPath, fmt.Errorf(
-			"%q: cannot determine Mackup version",
-			mackupVersionData,
-		)
-	}
-	mackupVersion := string(mackupVersionMatch[1])
+	mackupBinaryAbsPath := chezmoi.NewAbsPath(mackupBinaryPathResolved)
 
-	libDirAbsPath := brewPrefix.JoinString("Cellar", "mackup", mackupVersion, "libexec", "lib")
+	libDirAbsPath := mackupBinaryAbsPath.Dir().Dir().JoinString("lib")
 	dirEntries, err := c.baseSystem.ReadDir(libDirAbsPath)
 	if err != nil {
 		return chezmoi.EmptyAbsPath, err
 	}
-	var pythonDirRelPath chezmoi.RelPath
+
 	for _, dirEntry := range dirEntries {
-		if dirEntry.IsDir() && strings.HasPrefix(dirEntry.Name(), "python") {
-			pythonDirRelPath = chezmoi.NewRelPath(dirEntry.Name())
-			break
+		if !dirEntry.IsDir() || !strings.HasPrefix(dirEntry.Name(), "python") {
+			continue
+		}
+		mackupApplicationsDirAbsPath := libDirAbsPath.JoinString(
+			dirEntry.Name(),
+			"site-packages",
+			"mackup",
+			"applications",
+		)
+		if fileInfo, err := c.baseSystem.Stat(mackupApplicationsDirAbsPath); err == nil &&
+			fileInfo.IsDir() {
+			return mackupApplicationsDirAbsPath, nil
 		}
 	}
-	if pythonDirRelPath.Empty() {
-		return chezmoi.EmptyAbsPath, fmt.Errorf(
-			"%s: could not find python directory",
-			libDirAbsPath,
-		)
-	}
 
-	return libDirAbsPath.Join(pythonDirRelPath).
-			JoinString("site-packages", "mackup", "applications"),
-		nil
+	return chezmoi.EmptyAbsPath, fmt.Errorf(
+		"%s: mackup application directory not found",
+		libDirAbsPath,
+	)
 }
 
 func parseMackupApplication(data []byte) (mackupApplicationConfig, error) {
